{-# LANGUAGE NoImplicitPrelude #-}
{-# LANGUAGE OverloadedStrings #-}
{- |
   Module      : Text.Pandoc.Emoji
   Copyright   : Copyright (C) 2015 John MacFarlane
   License     : GNU GPL, version 2 or above

   Maintainer  : John MacFarlane <jgm@berkeley.edu>
   Stability   : alpha
   Portability : portable

Emoji symbol lookup from canonical string identifier.
-}
module Text.Pandoc.Emoji ( emojis, emojiToInline ) where
import Prelude
import qualified Data.Map as M
import qualified Data.Text as T
import Text.Pandoc.Definition (Inline (Span, Str))

emojis :: M.Map T.Text T.Text
emojis = M.fromList
  [("+1","\128077")
  ,("-1","\128078")
  ,("100","\128175")
  ,("1234","\128290")
  ,("1st_place_medal","\129351")
  ,("2nd_place_medal","\129352")
  ,("3rd_place_medal","\129353")
  ,("8ball","\127921")
  ,("a","\127344\65039")
  ,("ab","\127374")
  ,("abacus","\129518")
  ,("abc","\128292")
  ,("abcd","\128289")
  ,("accept","\127569")
  ,("adhesive_bandage","\129657")
  ,("adult","\129489")
  ,("aerial_tramway","\128673")
  ,("afghanistan","\127462\127467")
  ,("airplane","\9992\65039")
  ,("aland_islands","\127462\127485")
  ,("alarm_clock","\9200")
  ,("albania","\127462\127473")
  ,("alembic","\9879")
  ,("algeria","\127465\127487")
  ,("alien","\128125")
  ,("ambulance","\128657")
  ,("american_samoa","\127462\127480")
  ,("amphora","\127994")
  ,("anchor","\9875")
  ,("andorra","\127462\127465")
  ,("angel","\128124")
  ,("anger","\128162")
  ,("angola","\127462\127476")
  ,("angry","\128544")
  ,("anguilla","\127462\127470")
  ,("anguished","\128551")
  ,("ant","\128028")
  ,("antarctica","\127462\127478")
  ,("antigua_barbuda","\127462\127468")
  ,("apple","\127822")
  ,("aquarius","\9810")
  ,("argentina","\127462\127479")
  ,("aries","\9800")
  ,("armenia","\127462\127474")
  ,("arrow_backward","\9664\65039")
  ,("arrow_double_down","\9196")
  ,("arrow_double_up","\9195")
  ,("arrow_down","\11015\65039")
  ,("arrow_down_small","\128317")
  ,("arrow_forward","\9654\65039")
  ,("arrow_heading_down","\10549\65039")
  ,("arrow_heading_up","\10548\65039")
  ,("arrow_left","\11013\65039")
  ,("arrow_lower_left","\8601\65039")
  ,("arrow_lower_right","\8600\65039")
  ,("arrow_right","\10145\65039")
  ,("arrow_right_hook","\8618\65039")
  ,("arrow_up","\11014\65039")
  ,("arrow_up_down","\8597\65039")
  ,("arrow_up_small","\128316")
  ,("arrow_upper_left","\8598\65039")
  ,("arrow_upper_right","\8599\65039")
  ,("arrows_clockwise","\128259")
  ,("arrows_counterclockwise","\128260")
  ,("art","\127912")
  ,("articulated_lorry","\128667")
  ,("artificial_satellite","\128752")
  ,("aruba","\127462\127484")
  ,("ascension_island","\127462\127464")
  ,("asterisk","*\65039\8419")
  ,("astonished","\128562")
  ,("athletic_shoe","\128095")
  ,("atm","\127975")
  ,("atom_symbol","\9883")
  ,("australia","\127462\127482")
  ,("austria","\127462\127481")
  ,("auto_rickshaw","\128762")
  ,("avocado","\129361")
  ,("axe","\129683")
  ,("azerbaijan","\127462\127487")
  ,("b","\127345\65039")
  ,("baby","\128118")
  ,("baby_bottle","\127868")
  ,("baby_chick","\128036")
  ,("baby_symbol","\128700")
  ,("back","\128281")
  ,("bacon","\129363")
  ,("badger","\129441")
  ,("badminton","\127992")
  ,("bagel","\129391")
  ,("baggage_claim","\128708")
  ,("baguette_bread","\129366")
  ,("bahamas","\127463\127480")
  ,("bahrain","\127463\127469")
  ,("balance_scale","\9878")
  ,("bald_man","\128104\8205\129458")
  ,("bald_woman","\128105\8205\129458")
  ,("ballet_shoes","\129648")
  ,("balloon","\127880")
  ,("ballot_box","\128499")
  ,("ballot_box_with_check","\9745\65039")
  ,("bamboo","\127885")
  ,("banana","\127820")
  ,("bangbang","\8252\65039")
  ,("bangladesh","\127463\127465")
  ,("banjo","\129685")
  ,("bank","\127974")
  ,("bar_chart","\128202")
  ,("barbados","\127463\127463")
  ,("barber","\128136")
  ,("baseball","\9918")
  ,("basket","\129530")
  ,("basketball","\127936")
  ,("basketball_man","\9977\65039\8205\9794\65039")
  ,("basketball_woman","\9977\65039\8205\9792\65039")
  ,("bat","\129415")
  ,("bath","\128704")
  ,("bathtub","\128705")
  ,("battery","\128267")
  ,("beach_umbrella","\127958")
  ,("bear","\128059")
  ,("bearded_person","\129492")
  ,("bed","\128719")
  ,("bee","\128029")
  ,("beer","\127866")
  ,("beers","\127867")
  ,("beetle","\128030")
  ,("beginner","\128304")
  ,("belarus","\127463\127486")
  ,("belgium","\127463\127466")
  ,("belize","\127463\127487")
  ,("bell","\128276")
  ,("bellhop_bell","\128718")
  ,("benin","\127463\127471")
  ,("bento","\127857")
  ,("bermuda","\127463\127474")
  ,("beverage_box","\129475")
  ,("bhutan","\127463\127481")
  ,("bicyclist","\128692")
  ,("bike","\128690")
  ,("biking_man","\128692\8205\9794")
  ,("biking_woman","\128692\8205\9792")
  ,("bikini","\128089")
  ,("billed_cap","\129506")
  ,("biohazard","\9763")
  ,("bird","\128038")
  ,("birthday","\127874")
  ,("black_circle","\9899")
  ,("black_flag","\127988")
  ,("black_heart","\128420")
  ,("black_joker","\127183")
  ,("black_large_square","\11035")
  ,("black_medium_small_square","\9726")
  ,("black_medium_square","\9724\65039")
  ,("black_nib","\10002\65039")
  ,("black_small_square","\9642\65039")
  ,("black_square_button","\128306")
  ,("blond_haired_man","\128113\8205\9794")
  ,("blond_haired_person","\128113")
  ,("blond_haired_woman","\128113\8205\9792")
  ,("blonde_woman","\128113\8205\9792")
  ,("blossom","\127804")
  ,("blowfish","\128033")
  ,("blue_book","\128216")
  ,("blue_car","\128665")
  ,("blue_heart","\128153")
  ,("blue_square","\128998")
  ,("blush","\128522")
  ,("boar","\128023")
  ,("boat","\9973")
  ,("bolivia","\127463\127476")
  ,("bomb","\128163")
  ,("bone","\129460")
  ,("book","\128214")
  ,("bookmark","\128278")
  ,("bookmark_tabs","\128209")
  ,("books","\128218")
  ,("boom","\128165")
  ,("boot","\128098")
  ,("bosnia_herzegovina","\127463\127462")
  ,("botswana","\127463\127484")
  ,("bouncing_ball_man","\9977\65039\8205\9794\65039")
  ,("bouncing_ball_person","\9977")
  ,("bouncing_ball_woman","\9977\65039\8205\9792\65039")
  ,("bouquet","\128144")
  ,("bouvet_island","\127463\127483")
  ,("bow","\128583")
  ,("bow_and_arrow","\127993")
  ,("bowing_man","\128583\8205\9794")
  ,("bowing_woman","\128583\8205\9792")
  ,("bowl_with_spoon","\129379")
  ,("bowling","\127923")
  ,("boxing_glove","\129354")
  ,("boy","\128102")
  ,("brain","\129504")
  ,("brazil","\127463\127479")
  ,("bread","\127838")
  ,("breast_feeding","\129329")
  ,("bricks","\129521")
  ,("bride_with_veil","\128112")
  ,("bridge_at_night","\127753")
  ,("briefcase","\128188")
  ,("british_indian_ocean_territory","\127470\127476")
  ,("british_virgin_islands","\127483\127468")
  ,("broccoli","\129382")
  ,("broken_heart","\128148")
  ,("broom","\129529")
  ,("brown_circle","\128996")
  ,("brown_heart","\129294")
  ,("brown_square","\129003")
  ,("brunei","\127463\127475")
  ,("bug","\128027")
  ,("building_construction","\127959")
  ,("bulb","\128161")
  ,("bulgaria","\127463\127468")
  ,("bullettrain_front","\128645")
  ,("bullettrain_side","\128644")
  ,("burkina_faso","\127463\127467")
  ,("burrito","\127791")
  ,("burundi","\127463\127470")
  ,("bus","\128652")
  ,("business_suit_levitating","\128372")
  ,("busstop","\128655")
  ,("bust_in_silhouette","\128100")
  ,("busts_in_silhouette","\128101")
  ,("butter","\129480")
  ,("butterfly","\129419")
  ,("cactus","\127797")
  ,("cake","\127856")
  ,("calendar","\128198")
  ,("call_me_hand","\129305")
  ,("calling","\128242")
  ,("cambodia","\127472\127469")
  ,("camel","\128043")
  ,("camera","\128247")
  ,("camera_flash","\128248")
  ,("cameroon","\127464\127474")
  ,("camping","\127957")
  ,("canada","\127464\127462")
  ,("canary_islands","\127470\127464")
  ,("cancer","\9803")
  ,("candle","\128367")
  ,("candy","\127852")
  ,("canned_food","\129387")
  ,("canoe","\128758")
  ,("cape_verde","\127464\127483")
  ,("capital_abcd","\128288")
  ,("capricorn","\9809")
  ,("car","\128663")
  ,("card_file_box","\128451")
  ,("card_index","\128199")
  ,("card_index_dividers","\128450")
  ,("caribbean_netherlands","\127463\127478")
  ,("carousel_horse","\127904")
  ,("carrot","\129365")
  ,("cartwheeling","\129336")
  ,("cat","\128049")
  ,("cat2","\128008")
  ,("cayman_islands","\127472\127486")
  ,("cd","\128191")
  ,("central_african_republic","\127464\127467")
  ,("ceuta_melilla","\127466\127462")
  ,("chad","\127481\127465")
  ,("chains","\9939")
  ,("chair","\129681")
  ,("champagne","\127870")
  ,("chart","\128185")
  ,("chart_with_downwards_trend","\128201")
  ,("chart_with_upwards_trend","\128200")
  ,("checkered_flag","\127937")
  ,("cheese","\129472")
  ,("cherries","\127826")
  ,("cherry_blossom","\127800")
  ,("chess_pawn","\9823")
  ,("chestnut","\127792")
  ,("chicken","\128020")
  ,("child","\129490")
  ,("children_crossing","\128696")
  ,("chile","\127464\127473")
  ,("chipmunk","\128063")
  ,("chocolate_bar","\127851")
  ,("chopsticks","\129378")
  ,("christmas_island","\127464\127485")
  ,("christmas_tree","\127876")
  ,("church","\9962")
  ,("cinema","\127910")
  ,("circus_tent","\127914")
  ,("city_sunrise","\127751")
  ,("city_sunset","\127750")
  ,("cityscape","\127961")
  ,("cl","\127377")
  ,("clamp","\128476")
  ,("clap","\128079")
  ,("clapper","\127916")
  ,("classical_building","\127963")
  ,("climbing","\129495")
  ,("climbing_man","\129495\8205\9794")
  ,("climbing_woman","\129495\8205\9792")
  ,("clinking_glasses","\129346")
  ,("clipboard","\128203")
  ,("clipperton_island","\127464\127477")
  ,("clock1","\128336")
  ,("clock10","\128345")
  ,("clock1030","\128357")
  ,("clock11","\128346")
  ,("clock1130","\128358")
  ,("clock12","\128347")
  ,("clock1230","\128359")
  ,("clock130","\128348")
  ,("clock2","\128337")
  ,("clock230","\128349")
  ,("clock3","\128338")
  ,("clock330","\128350")
  ,("clock4","\128339")
  ,("clock430","\128351")
  ,("clock5","\128340")
  ,("clock530","\128352")
  ,("clock6","\128341")
  ,("clock630","\128353")
  ,("clock7","\128342")
  ,("clock730","\128354")
  ,("clock8","\128343")
  ,("clock830","\128355")
  ,("clock9","\128344")
  ,("clock930","\128356")
  ,("closed_book","\128213")
  ,("closed_lock_with_key","\128272")
  ,("closed_umbrella","\127746")
  ,("cloud","\9729\65039")
  ,("cloud_with_lightning","\127785")
  ,("cloud_with_lightning_and_rain","\9928")
  ,("cloud_with_rain","\127783")
  ,("cloud_with_snow","\127784")
  ,("clown_face","\129313")
  ,("clubs","\9827\65039")
  ,("cn","\127464\127475")
  ,("coat","\129509")
  ,("cocktail","\127864")
  ,("coconut","\129381")
  ,("cocos_islands","\127464\127464")
  ,("coffee","\9749")
  ,("coffin","\9904")
  ,("cold_face","\129398")
  ,("cold_sweat","\128560")
  ,("collision","\128165")
  ,("colombia","\127464\127476")
  ,("comet","\9732")
  ,("comoros","\127472\127474")
  ,("compass","\129517")
  ,("computer","\128187")
  ,("computer_mouse","\128433")
  ,("confetti_ball","\127882")
  ,("confounded","\128534")
  ,("confused","\128533")
  ,("congo_brazzaville","\127464\127468")
  ,("congo_kinshasa","\127464\127465")
  ,("congratulations","\12951\65039")
  ,("construction","\128679")
  ,("construction_worker","\128119")
  ,("construction_worker_man","\128119\8205\9794")
  ,("construction_worker_woman","\128119\8205\9792")
  ,("control_knobs","\127899")
  ,("convenience_store","\127978")
  ,("cook_islands","\127464\127472")
  ,("cookie","\127850")
  ,("cool","\127378")
  ,("cop","\128110")
  ,("copyright","\169\65039")
  ,("corn","\127805")
  ,("costa_rica","\127464\127479")
  ,("cote_divoire","\127464\127470")
  ,("couch_and_lamp","\128715")
  ,("couple","\128107")
  ,("couple_with_heart","\128145")
  ,("couple_with_heart_man_man"
   , "\128104\8205\10084\65039\8205\128104"
   )
  ,("couple_with_heart_woman_man"
   , "\128105\8205\10084\65039\8205\128104"
   )
  ,("couple_with_heart_woman_woman"
   , "\128105\8205\10084\65039\8205\128105"
   )
  ,("couplekiss","\128143")
  ,("couplekiss_man_man"
   , "\128104\8205\10084\65039\8205\128139\8205\128104"
   )
  ,("couplekiss_man_woman"
   , "\128105\8205\10084\65039\8205\128139\8205\128104"
   )
  ,("couplekiss_woman_woman"
   , "\128105\8205\10084\65039\8205\128139\8205\128105"
   )
  ,("cow","\128046")
  ,("cow2","\128004")
  ,("cowboy_hat_face","\129312")
  ,("crab","\129408")
  ,("crayon","\128397")
  ,("credit_card","\128179")
  ,("crescent_moon","\127769")
  ,("cricket","\129431")
  ,("cricket_game","\127951")
  ,("croatia","\127469\127479")
  ,("crocodile","\128010")
  ,("croissant","\129360")
  ,("crossed_fingers","\129310")
  ,("crossed_flags","\127884")
  ,("crossed_swords","\9876")
  ,("crown","\128081")
  ,("cry","\128546")
  ,("crying_cat_face","\128575")
  ,("crystal_ball","\128302")
  ,("cuba","\127464\127482")
  ,("cucumber","\129362")
  ,("cup_with_straw","\129380")
  ,("cupcake","\129473")
  ,("cupid","\128152")
  ,("curacao","\127464\127484")
  ,("curling_stone","\129356")
  ,("curly_haired_man","\128104\8205\129457")
  ,("curly_haired_woman","\128105\8205\129457")
  ,("curly_loop","\10160")
  ,("currency_exchange","\128177")
  ,("curry","\127835")
  ,("cursing_face","\129324")
  ,("custard","\127854")
  ,("customs","\128707")
  ,("cut_of_meat","\129385")
  ,("cyclone","\127744")
  ,("cyprus","\127464\127486")
  ,("czech_republic","\127464\127487")
  ,("dagger","\128481")
  ,("dancer","\128131")
  ,("dancers","\128111")
  ,("dancing_men","\128111\8205\9794")
  ,("dancing_women","\128111\8205\9792")
  ,("dango","\127841")
  ,("dark_sunglasses","\128374")
  ,("dart","\127919")
  ,("dash","\128168")
  ,("date","\128197")
  ,("de","\127465\127466")
  ,("deaf_man","\129487\8205\9794")
  ,("deaf_person","\129487")
  ,("deaf_woman","\129487\8205\9792")
  ,("deciduous_tree","\127795")
  ,("deer","\129420")
  ,("denmark","\127465\127472")
  ,("department_store","\127980")
  ,("derelict_house","\127962")
  ,("desert","\127964")
  ,("desert_island","\127965")
  ,("desktop_computer","\128421")
  ,("detective","\128373")
  ,("diamond_shape_with_a_dot_inside","\128160")
  ,("diamonds","\9830\65039")
  ,("diego_garcia","\127465\127468")
  ,("disappointed","\128542")
  ,("disappointed_relieved","\128549")
  ,("diving_mask","\129343")
  ,("diya_lamp","\129684")
  ,("dizzy","\128171")
  ,("dizzy_face","\128565")
  ,("djibouti","\127465\127471")
  ,("dna","\129516")
  ,("do_not_litter","\128687")
  ,("dog","\128054")
  ,("dog2","\128021")
  ,("dollar","\128181")
  ,("dolls","\127886")
  ,("dolphin","\128044")
  ,("dominica","\127465\127474")
  ,("dominican_republic","\127465\127476")
  ,("door","\128682")
  ,("doughnut","\127849")
  ,("dove","\128330")
  ,("dragon","\128009")
  ,("dragon_face","\128050")
  ,("dress","\128087")
  ,("dromedary_camel","\128042")
  ,("drooling_face","\129316")
  ,("drop_of_blood","\129656")
  ,("droplet","\128167")
  ,("drum","\129345")
  ,("duck","\129414")
  ,("dumpling","\129375")
  ,("dvd","\128192")
  ,("e-mail","\128231")
  ,("eagle","\129413")
  ,("ear","\128066")
  ,("ear_of_rice","\127806")
  ,("ear_with_hearing_aid","\129467")
  ,("earth_africa","\127757")
  ,("earth_americas","\127758")
  ,("earth_asia","\127759")
  ,("ecuador","\127466\127464")
  ,("egg","\129370")
  ,("eggplant","\127814")
  ,("egypt","\127466\127468")
  ,("eight","8\65039\8419")
  ,("eight_pointed_black_star","\10036\65039")
  ,("eight_spoked_asterisk","\10035\65039")
  ,("eject_button","\9167\65039")
  ,("el_salvador","\127480\127483")
  ,("electric_plug","\128268")
  ,("elephant","\128024")
  ,("elf","\129501")
  ,("elf_man","\129501\8205\9794")
  ,("elf_woman","\129501\8205\9792")
  ,("email","\9993\65039")
  ,("end","\128282")
  ,("england"
   , "\127988\917607\917602\917605\917614\917607\917631"
   )
  ,("envelope","\9993\65039")
  ,("envelope_with_arrow","\128233")
  ,("equatorial_guinea","\127468\127478")
  ,("eritrea","\127466\127479")
  ,("es","\127466\127480")
  ,("estonia","\127466\127466")
  ,("ethiopia","\127466\127481")
  ,("eu","\127466\127482")
  ,("euro","\128182")
  ,("european_castle","\127984")
  ,("european_post_office","\127972")
  ,("european_union","\127466\127482")
  ,("evergreen_tree","\127794")
  ,("exclamation","\10071")
  ,("exploding_head","\129327")
  ,("expressionless","\128529")
  ,("eye","\128065")
  ,("eye_speech_bubble","\128065\65039\8205\128488\65039")
  ,("eyeglasses","\128083")
  ,("eyes","\128064")
  ,("face_with_head_bandage","\129301")
  ,("face_with_thermometer","\129298")
  ,("facepalm","\129318")
  ,("facepunch","\128074")
  ,("factory","\127981")
  ,("fairy","\129498")
  ,("fairy_man","\129498\8205\9794")
  ,("fairy_woman","\129498\8205\9792")
  ,("falafel","\129478")
  ,("falkland_islands","\127467\127472")
  ,("fallen_leaf","\127810")
  ,("family","\128106")
  ,("family_man_boy","\128104\8205\128102")
  ,("family_man_boy_boy","\128104\8205\128102\8205\128102")
  ,("family_man_girl","\128104\8205\128103")
  ,("family_man_girl_boy","\128104\8205\128103\8205\128102")
  ,("family_man_girl_girl","\128104\8205\128103\8205\128103")
  ,("family_man_man_boy","\128104\8205\128104\8205\128102")
  ,("family_man_man_boy_boy"
   , "\128104\8205\128104\8205\128102\8205\128102"
   )
  ,("family_man_man_girl","\128104\8205\128104\8205\128103")
  ,("family_man_man_girl_boy"
   , "\128104\8205\128104\8205\128103\8205\128102"
   )
  ,("family_man_man_girl_girl"
   , "\128104\8205\128104\8205\128103\8205\128103"
   )
  ,("family_man_woman_boy","\128104\8205\128105\8205\128102")
  ,("family_man_woman_boy_boy"
   , "\128104\8205\128105\8205\128102\8205\128102"
   )
  ,("family_man_woman_girl","\128104\8205\128105\8205\128103")
  ,("family_man_woman_girl_boy"
   , "\128104\8205\128105\8205\128103\8205\128102"
   )
  ,("family_man_woman_girl_girl"
   , "\128104\8205\128105\8205\128103\8205\128103"
   )
  ,("family_woman_boy","\128105\8205\128102")
  ,("family_woman_boy_boy","\128105\8205\128102\8205\128102")
  ,("family_woman_girl","\128105\8205\128103")
  ,("family_woman_girl_boy","\128105\8205\128103\8205\128102")
  ,("family_woman_girl_girl","\128105\8205\128103\8205\128103")
  ,("family_woman_woman_boy","\128105\8205\128105\8205\128102")
  ,("family_woman_woman_boy_boy"
   , "\128105\8205\128105\8205\128102\8205\128102"
   )
  ,("family_woman_woman_girl","\128105\8205\128105\8205\128103")
  ,("family_woman_woman_girl_boy"
   , "\128105\8205\128105\8205\128103\8205\128102"
   )
  ,("family_woman_woman_girl_girl"
   , "\128105\8205\128105\8205\128103\8205\128103"
   )
  ,("faroe_islands","\127467\127476")
  ,("fast_forward","\9193")
  ,("fax","\128224")
  ,("fearful","\128552")
  ,("feet","\128062")
  ,("female_detective","\128373\65039\8205\9792\65039")
  ,("female_sign","\9792\65039")
  ,("ferris_wheel","\127905")
  ,("ferry","\9972")
  ,("field_hockey","\127953")
  ,("fiji","\127467\127471")
  ,("file_cabinet","\128452")
  ,("file_folder","\128193")
  ,("film_projector","\128253")
  ,("film_strip","\127902")
  ,("finland","\127467\127470")
  ,("fire","\128293")
  ,("fire_engine","\128658")
  ,("fire_extinguisher","\129519")
  ,("firecracker","\129512")
  ,("fireworks","\127878")
  ,("first_quarter_moon","\127763")
  ,("first_quarter_moon_with_face","\127771")
  ,("fish","\128031")
  ,("fish_cake","\127845")
  ,("fishing_pole_and_fish","\127907")
  ,("fist","\9994")
  ,("fist_left","\129307")
  ,("fist_oncoming","\128074")
  ,("fist_raised","\9994")
  ,("fist_right","\129308")
  ,("five","5\65039\8419")
  ,("flags","\127887")
  ,("flamingo","\129449")
  ,("flashlight","\128294")
  ,("flat_shoe","\129407")
  ,("fleur_de_lis","\9884")
  ,("flight_arrival","\128748")
  ,("flight_departure","\128747")
  ,("flipper","\128044")
  ,("floppy_disk","\128190")
  ,("flower_playing_cards","\127924")
  ,("flushed","\128563")
  ,("flying_disc","\129359")
  ,("flying_saucer","\128760")
  ,("fog","\127787")
  ,("foggy","\127745")
  ,("foot","\129462")
  ,("football","\127944")
  ,("footprints","\128099")
  ,("fork_and_knife","\127860")
  ,("fortune_cookie","\129376")
  ,("fountain","\9970")
  ,("fountain_pen","\128395")
  ,("four","4\65039\8419")
  ,("four_leaf_clover","\127808")
  ,("fox_face","\129418")
  ,("fr","\127467\127479")
  ,("framed_picture","\128444")
  ,("free","\127379")
  ,("french_guiana","\127468\127467")
  ,("french_polynesia","\127477\127467")
  ,("french_southern_territories","\127481\127467")
  ,("fried_egg","\127859")
  ,("fried_shrimp","\127844")
  ,("fries","\127839")
  ,("frog","\128056")
  ,("frowning","\128550")
  ,("frowning_face","\9785")
  ,("frowning_man","\128589\8205\9794")
  ,("frowning_person","\128589")
  ,("frowning_woman","\128589\8205\9792")
  ,("fu","\128405")
  ,("fuelpump","\9981")
  ,("full_moon","\127765")
  ,("full_moon_with_face","\127773")
  ,("funeral_urn","\9905")
  ,("gabon","\127468\127462")
  ,("gambia","\127468\127474")
  ,("game_die","\127922")
  ,("garlic","\129476")
  ,("gb","\127468\127463")
  ,("gear","\9881")
  ,("gem","\128142")
  ,("gemini","\9802")
  ,("genie","\129502")
  ,("genie_man","\129502\8205\9794")
  ,("genie_woman","\129502\8205\9792")
  ,("georgia","\127468\127466")
  ,("ghana","\127468\127469")
  ,("ghost","\128123")
  ,("gibraltar","\127468\127470")
  ,("gift","\127873")
  ,("gift_heart","\128157")
  ,("giraffe","\129426")
  ,("girl","\128103")
  ,("globe_with_meridians","\127760")
  ,("gloves","\129508")
  ,("goal_net","\129349")
  ,("goat","\128016")
  ,("goggles","\129405")
  ,("golf","\9971")
  ,("golfing","\127948")
  ,("golfing_man","\127948\65039\8205\9794\65039")
  ,("golfing_woman","\127948\65039\8205\9792\65039")
  ,("gorilla","\129421")
  ,("grapes","\127815")
  ,("greece","\127468\127479")
  ,("green_apple","\127823")
  ,("green_book","\128215")
  ,("green_circle","\128994")
  ,("green_heart","\128154")
  ,("green_salad","\129367")
  ,("green_square","\129001")
  ,("greenland","\127468\127473")
  ,("grenada","\127468\127465")
  ,("grey_exclamation","\10069")
  ,("grey_question","\10068")
  ,("grimacing","\128556")
  ,("grin","\128513")
  ,("grinning","\128512")
  ,("guadeloupe","\127468\127477")
  ,("guam","\127468\127482")
  ,("guard","\128130")
  ,("guardsman","\128130\8205\9794")
  ,("guardswoman","\128130\8205\9792")
  ,("guatemala","\127468\127481")
  ,("guernsey","\127468\127468")
  ,("guide_dog","\129454")
  ,("guinea","\127468\127475")
  ,("guinea_bissau","\127468\127484")
  ,("guitar","\127928")
  ,("gun","\128299")
  ,("guyana","\127468\127486")
  ,("haircut","\128135")
  ,("haircut_man","\128135\8205\9794")
  ,("haircut_woman","\128135\8205\9792")
  ,("haiti","\127469\127481")
  ,("hamburger","\127828")
  ,("hammer","\128296")
  ,("hammer_and_pick","\9874")
  ,("hammer_and_wrench","\128736")
  ,("hamster","\128057")
  ,("hand","\9995")
  ,("hand_over_mouth","\129325")
  ,("handbag","\128092")
  ,("handball_person","\129342")
  ,("handshake","\129309")
  ,("hankey","\128169")
  ,("hash","#\65039\8419")
  ,("hatched_chick","\128037")
  ,("hatching_chick","\128035")
  ,("headphones","\127911")
  ,("hear_no_evil","\128585")
  ,("heard_mcdonald_islands","\127469\127474")
  ,("heart","\10084\65039")
  ,("heart_decoration","\128159")
  ,("heart_eyes","\128525")
  ,("heart_eyes_cat","\128571")
  ,("heartbeat","\128147")
  ,("heartpulse","\128151")
  ,("hearts","\9829\65039")
  ,("heavy_check_mark","\10004\65039")
  ,("heavy_division_sign","\10135")
  ,("heavy_dollar_sign","\128178")
  ,("heavy_exclamation_mark","\10071")
  ,("heavy_heart_exclamation","\10083\65039")
  ,("heavy_minus_sign","\10134")
  ,("heavy_multiplication_x","\10006\65039")
  ,("heavy_plus_sign","\10133")
  ,("hedgehog","\129428")
  ,("helicopter","\128641")
  ,("herb","\127807")
  ,("hibiscus","\127802")
  ,("high_brightness","\128262")
  ,("high_heel","\128096")
  ,("hiking_boot","\129406")
  ,("hindu_temple","\128725")
  ,("hippopotamus","\129435")
  ,("hocho","\128298")
  ,("hole","\128371")
  ,("honduras","\127469\127475")
  ,("honey_pot","\127855")
  ,("honeybee","\128029")
  ,("hong_kong","\127469\127472")
  ,("horse","\128052")
  ,("horse_racing","\127943")
  ,("hospital","\127973")
  ,("hot_face","\129397")
  ,("hot_pepper","\127798")
  ,("hotdog","\127789")
  ,("hotel","\127976")
  ,("hotsprings","\9832\65039")
  ,("hourglass","\8987")
  ,("hourglass_flowing_sand","\9203")
  ,("house","\127968")
  ,("house_with_garden","\127969")
  ,("houses","\127960")
  ,("hugs","\129303")
  ,("hungary","\127469\127482")
  ,("hushed","\128559")
  ,("ice_cream","\127848")
  ,("ice_cube","\129482")
  ,("ice_hockey","\127954")
  ,("ice_skate","\9976")
  ,("icecream","\127846")
  ,("iceland","\127470\127480")
  ,("id","\127380")
  ,("ideograph_advantage","\127568")
  ,("imp","\128127")
  ,("inbox_tray","\128229")
  ,("incoming_envelope","\128232")
  ,("india","\127470\127475")
  ,("indonesia","\127470\127465")
  ,("infinity","\9854")
  ,("information_desk_person","\128129")
  ,("information_source","\8505\65039")
  ,("innocent","\128519")
  ,("interrobang","\8265\65039")
  ,("iphone","\128241")
  ,("iran","\127470\127479")
  ,("iraq","\127470\127478")
  ,("ireland","\127470\127466")
  ,("isle_of_man","\127470\127474")
  ,("israel","\127470\127473")
  ,("it","\127470\127481")
  ,("izakaya_lantern","\127982")
  ,("jack_o_lantern","\127875")
  ,("jamaica","\127471\127474")
  ,("japan","\128510")
  ,("japanese_castle","\127983")
  ,("japanese_goblin","\128122")
  ,("japanese_ogre","\128121")
  ,("jeans","\128086")
  ,("jersey","\127471\127466")
  ,("jigsaw","\129513")
  ,("jordan","\127471\127476")
  ,("joy","\128514")
  ,("joy_cat","\128569")
  ,("joystick","\128377")
  ,("jp","\127471\127477")
  ,("juggling_person","\129337")
  ,("kaaba","\128331")
  ,("kangaroo","\129432")
  ,("kazakhstan","\127472\127487")
  ,("kenya","\127472\127466")
  ,("key","\128273")
  ,("keyboard","\9000")
  ,("keycap_ten","\128287")
  ,("kick_scooter","\128756")
  ,("kimono","\128088")
  ,("kiribati","\127472\127470")
  ,("kiss","\128139")
  ,("kissing","\128535")
  ,("kissing_cat","\128573")
  ,("kissing_closed_eyes","\128538")
  ,("kissing_heart","\128536")
  ,("kissing_smiling_eyes","\128537")
  ,("kite","\129665")
  ,("kiwi_fruit","\129373")
  ,("kneeling_man","\129486\8205\9794")
  ,("kneeling_person","\129486")
  ,("kneeling_woman","\129486\8205\9792")
  ,("knife","\128298")
  ,("koala","\128040")
  ,("koko","\127489")
  ,("kosovo","\127485\127472")
  ,("kr","\127472\127479")
  ,("kuwait","\127472\127484")
  ,("kyrgyzstan","\127472\127468")
  ,("lab_coat","\129404")
  ,("label","\127991")
  ,("lacrosse","\129357")
  ,("lantern","\127982")
  ,("laos","\127473\127462")
  ,("large_blue_circle","\128309")
  ,("large_blue_diamond","\128311")
  ,("large_orange_diamond","\128310")
  ,("last_quarter_moon","\127767")
  ,("last_quarter_moon_with_face","\127772")
  ,("latin_cross","\10013\65039")
  ,("latvia","\127473\127483")
  ,("laughing","\128518")
  ,("leafy_green","\129388")
  ,("leaves","\127811")
  ,("lebanon","\127473\127463")
  ,("ledger","\128210")
  ,("left_luggage","\128709")
  ,("left_right_arrow","\8596\65039")
  ,("left_speech_bubble","\128488")
  ,("leftwards_arrow_with_hook","\8617\65039")
  ,("leg","\129461")
  ,("lemon","\127819")
  ,("leo","\9804")
  ,("leopard","\128006")
  ,("lesotho","\127473\127480")
  ,("level_slider","\127898")
  ,("liberia","\127473\127479")
  ,("libra","\9806")
  ,("libya","\127473\127486")
  ,("liechtenstein","\127473\127470")
  ,("light_rail","\128648")
  ,("link","\128279")
  ,("lion","\129409")
  ,("lips","\128068")
  ,("lipstick","\128132")
  ,("lithuania","\127473\127481")
  ,("lizard","\129422")
  ,("llama","\129433")
  ,("lobster","\129438")
  ,("lock","\128274")
  ,("lock_with_ink_pen","\128271")
  ,("lollipop","\127853")
  ,("loop","\10175")
  ,("lotion_bottle","\129524")
  ,("lotus_position","\129496")
  ,("lotus_position_man","\129496\8205\9794")
  ,("lotus_position_woman","\129496\8205\9792")
  ,("loud_sound","\128266")
  ,("loudspeaker","\128226")
  ,("love_hotel","\127977")
  ,("love_letter","\128140")
  ,("love_you_gesture","\129311")
  ,("low_brightness","\128261")
  ,("luggage","\129523")
  ,("luxembourg","\127473\127482")
  ,("lying_face","\129317")
  ,("m","\9410\65039")
  ,("macau","\127474\127476")
  ,("macedonia","\127474\127472")
  ,("madagascar","\127474\127468")
  ,("mag","\128269")
  ,("mag_right","\128270")
  ,("mage","\129497")
  ,("mage_man","\129497\8205\9794")
  ,("mage_woman","\129497\8205\9792")
  ,("magnet","\129522")
  ,("mahjong","\126980")
  ,("mailbox","\128235")
  ,("mailbox_closed","\128234")
  ,("mailbox_with_mail","\128236")
  ,("mailbox_with_no_mail","\128237")
  ,("malawi","\127474\127484")
  ,("malaysia","\127474\127486")
  ,("maldives","\127474\127483")
  ,("male_detective","\128373\65039\8205\9794\65039")
  ,("male_sign","\9794\65039")
  ,("mali","\127474\127473")
  ,("malta","\127474\127481")
  ,("man","\128104")
  ,("man_artist","\128104\8205\127912")
  ,("man_astronaut","\128104\8205\128640")
  ,("man_cartwheeling","\129336\8205\9794")
  ,("man_cook","\128104\8205\127859")
  ,("man_dancing","\128378")
  ,("man_facepalming","\129318\8205\9794")
  ,("man_factory_worker","\128104\8205\127981")
  ,("man_farmer","\128104\8205\127806")
  ,("man_firefighter","\128104\8205\128658")
  ,("man_health_worker","\128104\8205\9877")
  ,("man_in_manual_wheelchair","\128104\8205\129469")
  ,("man_in_motorized_wheelchair","\128104\8205\129468")
  ,("man_in_tuxedo","\129333")
  ,("man_judge","\128104\8205\9878")
  ,("man_juggling","\129337\8205\9794")
  ,("man_mechanic","\128104\8205\128295")
  ,("man_office_worker","\128104\8205\128188")
  ,("man_pilot","\128104\8205\9992")
  ,("man_playing_handball","\129342\8205\9794")
  ,("man_playing_water_polo","\129341\8205\9794")
  ,("man_scientist","\128104\8205\128300")
  ,("man_shrugging","\129335\8205\9794")
  ,("man_singer","\128104\8205\127908")
  ,("man_student","\128104\8205\127891")
  ,("man_teacher","\128104\8205\127979")
  ,("man_technologist","\128104\8205\128187")
  ,("man_with_gua_pi_mao","\128114")
  ,("man_with_probing_cane","\128104\8205\129455")
  ,("man_with_turban","\128115\8205\9794")
  ,("mandarin","\127818")
  ,("mango","\129389")
  ,("mans_shoe","\128094")
  ,("mantelpiece_clock","\128368")
  ,("manual_wheelchair","\129469")
  ,("maple_leaf","\127809")
  ,("marshall_islands","\127474\127469")
  ,("martial_arts_uniform","\129355")
  ,("martinique","\127474\127478")
  ,("mask","\128567")
  ,("massage","\128134")
  ,("massage_man","\128134\8205\9794")
  ,("massage_woman","\128134\8205\9792")
  ,("mate","\129481")
  ,("mauritania","\127474\127479")
  ,("mauritius","\127474\127482")
  ,("mayotte","\127486\127481")
  ,("meat_on_bone","\127830")
  ,("mechanical_arm","\129470")
  ,("mechanical_leg","\129471")
  ,("medal_military","\127894")
  ,("medal_sports","\127941")
  ,("medical_symbol","\9877")
  ,("mega","\128227")
  ,("melon","\127816")
  ,("memo","\128221")
  ,("men_wrestling","\129340\8205\9794")
  ,("menorah","\128334")
  ,("mens","\128697")
  ,("mermaid","\129500\8205\9792")
  ,("merman","\129500\8205\9794")
  ,("merperson","\129500")
  ,("metal","\129304")
  ,("metro","\128647")
  ,("mexico","\127474\127485")
  ,("microbe","\129440")
  ,("micronesia","\127467\127474")
  ,("microphone","\127908")
  ,("microscope","\128300")
  ,("middle_finger","\128405")
  ,("milk_glass","\129371")
  ,("milky_way","\127756")
  ,("minibus","\128656")
  ,("minidisc","\128189")
  ,("mobile_phone_off","\128244")
  ,("moldova","\127474\127465")
  ,("monaco","\127474\127464")
  ,("money_mouth_face","\129297")
  ,("money_with_wings","\128184")
  ,("moneybag","\128176")
  ,("mongolia","\127474\127475")
  ,("monkey","\128018")
  ,("monkey_face","\128053")
  ,("monocle_face","\129488")
  ,("monorail","\128669")
  ,("montenegro","\127474\127466")
  ,("montserrat","\127474\127480")
  ,("moon","\127764")
  ,("moon_cake","\129390")
  ,("morocco","\127474\127462")
  ,("mortar_board","\127891")
  ,("mosque","\128332")
  ,("mosquito","\129439")
  ,("motor_boat","\128741")
  ,("motor_scooter","\128757")
  ,("motorcycle","\127949")
  ,("motorized_wheelchair","\129468")
  ,("motorway","\128739")
  ,("mount_fuji","\128507")
  ,("mountain","\9968")
  ,("mountain_bicyclist","\128693")
  ,("mountain_biking_man","\128693\8205\9794")
  ,("mountain_biking_woman","\128693\8205\9792")
  ,("mountain_cableway","\128672")
  ,("mountain_railway","\128670")
  ,("mountain_snow","\127956")
  ,("mouse","\128045")
  ,("mouse2","\128001")
  ,("movie_camera","\127909")
  ,("moyai","\128511")
  ,("mozambique","\127474\127487")
  ,("mrs_claus","\129334")
  ,("muscle","\128170")
  ,("mushroom","\127812")
  ,("musical_keyboard","\127929")
  ,("musical_note","\127925")
  ,("musical_score","\127932")
  ,("mute","\128263")
  ,("myanmar","\127474\127474")
  ,("nail_care","\128133")
  ,("name_badge","\128219")
  ,("namibia","\127475\127462")
  ,("national_park","\127966")
  ,("nauru","\127475\127479")
  ,("nauseated_face","\129314")
  ,("nazar_amulet","\129535")
  ,("necktie","\128084")
  ,("negative_squared_cross_mark","\10062")
  ,("nepal","\127475\127477")
  ,("nerd_face","\129299")
  ,("netherlands","\127475\127473")
  ,("neutral_face","\128528")
  ,("new","\127381")
  ,("new_caledonia","\127475\127464")
  ,("new_moon","\127761")
  ,("new_moon_with_face","\127770")
  ,("new_zealand","\127475\127487")
  ,("newspaper","\128240")
  ,("newspaper_roll","\128478")
  ,("next_track_button","\9197")
  ,("ng","\127382")
  ,("ng_man","\128581\8205\9794")
  ,("ng_woman","\128581\8205\9792")
  ,("nicaragua","\127475\127470")
  ,("niger","\127475\127466")
  ,("nigeria","\127475\127468")
  ,("night_with_stars","\127747")
  ,("nine","9\65039\8419")
  ,("niue","\127475\127482")
  ,("no_bell","\128277")
  ,("no_bicycles","\128691")
  ,("no_entry","\9940")
  ,("no_entry_sign","\128683")
  ,("no_good","\128581")
  ,("no_good_man","\128581\8205\9794")
  ,("no_good_woman","\128581\8205\9792")
  ,("no_mobile_phones","\128245")
  ,("no_mouth","\128566")
  ,("no_pedestrians","\128695")
  ,("no_smoking","\128685")
  ,("non-potable_water","\128689")
  ,("norfolk_island","\127475\127467")
  ,("north_korea","\127472\127477")
  ,("northern_mariana_islands","\127474\127477")
  ,("norway","\127475\127476")
  ,("nose","\128067")
  ,("notebook","\128211")
  ,("notebook_with_decorative_cover","\128212")
  ,("notes","\127926")
  ,("nut_and_bolt","\128297")
  ,("o","\11093")
  ,("o2","\127358\65039")
  ,("ocean","\127754")
  ,("octopus","\128025")
  ,("oden","\127842")
  ,("office","\127970")
  ,("oil_drum","\128738")
  ,("ok","\127383")
  ,("ok_hand","\128076")
  ,("ok_man","\128582\8205\9794")
  ,("ok_person","\128582")
  ,("ok_woman","\128582\8205\9792")
  ,("old_key","\128477")
  ,("older_adult","\129491")
  ,("older_man","\128116")
  ,("older_woman","\128117")
  ,("om","\128329")
  ,("oman","\127476\127474")
  ,("on","\128283")
  ,("oncoming_automobile","\128664")
  ,("oncoming_bus","\128653")
  ,("oncoming_police_car","\128660")
  ,("oncoming_taxi","\128662")
  ,("one","1\65039\8419")
  ,("one_piece_swimsuit","\129649")
  ,("onion","\129477")
  ,("open_book","\128214")
  ,("open_file_folder","\128194")
  ,("open_hands","\128080")
  ,("open_mouth","\128558")
  ,("open_umbrella","\9730\65039")
  ,("ophiuchus","\9934")
  ,("orange","\127818")
  ,("orange_book","\128217")
  ,("orange_circle","\128992")
  ,("orange_heart","\129505")
  ,("orange_square","\128999")
  ,("orangutan","\129447")
  ,("orthodox_cross","\9766")
  ,("otter","\129446")
  ,("outbox_tray","\128228")
  ,("owl","\129417")
  ,("ox","\128002")
  ,("oyster","\129450")
  ,("package","\128230")
  ,("page_facing_up","\128196")
  ,("page_with_curl","\128195")
  ,("pager","\128223")
  ,("paintbrush","\128396")
  ,("pakistan","\127477\127472")
  ,("palau","\127477\127484")
  ,("palestinian_territories","\127477\127480")
  ,("palm_tree","\127796")
  ,("palms_up_together","\129330")
  ,("panama","\127477\127462")
  ,("pancakes","\129374")
  ,("panda_face","\128060")
  ,("paperclip","\128206")
  ,("paperclips","\128391")
  ,("papua_new_guinea","\127477\127468")
  ,("parachute","\129666")
  ,("paraguay","\127477\127486")
  ,("parasol_on_ground","\9969")
  ,("parking","\127359\65039")
  ,("parrot","\129436")
  ,("part_alternation_mark","\12349\65039")
  ,("partly_sunny","\9925")
  ,("partying_face","\129395")
  ,("passenger_ship","\128755")
  ,("passport_control","\128706")
  ,("pause_button","\9208")
  ,("paw_prints","\128062")
  ,("peace_symbol","\9774")
  ,("peach","\127825")
  ,("peacock","\129434")
  ,("peanuts","\129372")
  ,("pear","\127824")
  ,("pen","\128394")
  ,("pencil","\128221")
  ,("pencil2","\9999\65039")
  ,("penguin","\128039")
  ,("pensive","\128532")
  ,("people_holding_hands","\129489\8205\129309\8205\129489")
  ,("performing_arts","\127917")
  ,("persevere","\128547")
  ,("person_fencing","\129338")
  ,("person_with_turban","\128115")
  ,("peru","\127477\127466")
  ,("petri_dish","\129515")
  ,("philippines","\127477\127469")
  ,("phone","\9742\65039")
  ,("pick","\9935")
  ,("pie","\129383")
  ,("pig","\128055")
  ,("pig2","\128022")
  ,("pig_nose","\128061")
  ,("pill","\128138")
  ,("pinching_hand","\129295")
  ,("pineapple","\127821")
  ,("ping_pong","\127955")
  ,("pirate_flag","\127988\8205\9760")
  ,("pisces","\9811")
  ,("pitcairn_islands","\127477\127475")
  ,("pizza","\127829")
  ,("place_of_worship","\128720")
  ,("plate_with_cutlery","\127869")
  ,("play_or_pause_button","\9199")
  ,("pleading_face","\129402")
  ,("point_down","\128071")
  ,("point_left","\128072")
  ,("point_right","\128073")
  ,("point_up","\9757\65039")
  ,("point_up_2","\128070")
  ,("poland","\127477\127473")
  ,("police_car","\128659")
  ,("police_officer","\128110")
  ,("policeman","\128110\8205\9794")
  ,("policewoman","\128110\8205\9792")
  ,("poodle","\128041")
  ,("poop","\128169")
  ,("popcorn","\127871")
  ,("portugal","\127477\127481")
  ,("post_office","\127971")
  ,("postal_horn","\128239")
  ,("postbox","\128238")
  ,("potable_water","\128688")
  ,("potato","\129364")
  ,("pouch","\128093")
  ,("poultry_leg","\127831")
  ,("pound","\128183")
  ,("pout","\128545")
  ,("pouting_cat","\128574")
  ,("pouting_face","\128590")
  ,("pouting_man","\128590\8205\9794")
  ,("pouting_woman","\128590\8205\9792")
  ,("pray","\128591")
  ,("prayer_beads","\128255")
  ,("pregnant_woman","\129328")
  ,("pretzel","\129384")
  ,("previous_track_button","\9198")
  ,("prince","\129332")
  ,("princess","\128120")
  ,("printer","\128424")
  ,("probing_cane","\129455")
  ,("puerto_rico","\127477\127479")
  ,("punch","\128074")
  ,("purple_circle","\128995")
  ,("purple_heart","\128156")
  ,("purple_square","\129002")
  ,("purse","\128091")
  ,("pushpin","\128204")
  ,("put_litter_in_its_place","\128686")
  ,("qatar","\127478\127462")
  ,("question","\10067")
  ,("rabbit","\128048")
  ,("rabbit2","\128007")
  ,("raccoon","\129437")
  ,("racehorse","\128014")
  ,("racing_car","\127950")
  ,("radio","\128251")
  ,("radio_button","\128280")
  ,("radioactive","\9762")
  ,("rage","\128545")
  ,("railway_car","\128643")
  ,("railway_track","\128740")
  ,("rainbow","\127752")
  ,("rainbow_flag","\127987\65039\8205\127752")
  ,("raised_back_of_hand","\129306")
  ,("raised_eyebrow","\129320")
  ,("raised_hand","\9995")
  ,("raised_hand_with_fingers_splayed","\128400")
  ,("raised_hands","\128588")
  ,("raising_hand","\128587")
  ,("raising_hand_man","\128587\8205\9794")
  ,("raising_hand_woman","\128587\8205\9792")
  ,("ram","\128015")
  ,("ramen","\127836")
  ,("rat","\128000")
  ,("razor","\129682")
  ,("receipt","\129534")
  ,("record_button","\9210")
  ,("recycle","\9851\65039")
  ,("red_car","\128663")
  ,("red_circle","\128308")
  ,("red_envelope","\129511")
  ,("red_haired_man","\128104\8205\129456")
  ,("red_haired_woman","\128105\8205\129456")
  ,("red_square","\128997")
  ,("registered","\174\65039")
  ,("relaxed","\9786\65039")
  ,("relieved","\128524")
  ,("reminder_ribbon","\127895")
  ,("repeat","\128257")
  ,("repeat_one","\128258")
  ,("rescue_worker_helmet","\9937")
  ,("restroom","\128699")
  ,("reunion","\127479\127466")
  ,("revolving_hearts","\128158")
  ,("rewind","\9194")
  ,("rhinoceros","\129423")
  ,("ribbon","\127872")
  ,("rice","\127834")
  ,("rice_ball","\127833")
  ,("rice_cracker","\127832")
  ,("rice_scene","\127889")
  ,("right_anger_bubble","\128495")
  ,("ring","\128141")
  ,("ringed_planet","\129680")
  ,("robot","\129302")
  ,("rocket","\128640")
  ,("rofl","\129315")
  ,("roll_eyes","\128580")
  ,("roll_of_paper","\129531")
  ,("roller_coaster","\127906")
  ,("romania","\127479\127476")
  ,("rooster","\128019")
  ,("rose","\127801")
  ,("rosette","\127989")
  ,("rotating_light","\128680")
  ,("round_pushpin","\128205")
  ,("rowboat","\128675")
  ,("rowing_man","\128675\8205\9794")
  ,("rowing_woman","\128675\8205\9792")
  ,("ru","\127479\127482")
  ,("rugby_football","\127945")
  ,("runner","\127939")
  ,("running","\127939")
  ,("running_man","\127939\8205\9794")
  ,("running_shirt_with_sash","\127933")
  ,("running_woman","\127939\8205\9792")
  ,("rwanda","\127479\127484")
  ,("sa","\127490\65039")
  ,("safety_pin","\129527")
  ,("safety_vest","\129466")
  ,("sagittarius","\9808")
  ,("sailboat","\9973")
  ,("sake","\127862")
  ,("salt","\129474")
  ,("samoa","\127484\127480")
  ,("san_marino","\127480\127474")
  ,("sandal","\128097")
  ,("sandwich","\129386")
  ,("santa","\127877")
  ,("sao_tome_principe","\127480\127481")
  ,("sari","\129403")
  ,("sassy_man","\128129\8205\9794")
  ,("sassy_woman","\128129\8205\9792")
  ,("satellite","\128225")
  ,("satisfied","\128518")
  ,("saudi_arabia","\127480\127462")
  ,("sauna_man","\129494\8205\9794")
  ,("sauna_person","\129494")
  ,("sauna_woman","\129494\8205\9792")
  ,("sauropod","\129429")
  ,("saxophone","\127927")
  ,("scarf","\129507")
  ,("school","\127979")
  ,("school_satchel","\127890")
  ,("scissors","\9986\65039")
  ,("scorpion","\129410")
  ,("scorpius","\9807")
  ,("scotland"
   , "\127988\917607\917602\917619\917603\917620\917631"
   )
  ,("scream","\128561")
  ,("scream_cat","\128576")
  ,("scroll","\128220")
  ,("seat","\128186")
  ,("secret","\12953\65039")
  ,("see_no_evil","\128584")
  ,("seedling","\127793")
  ,("selfie","\129331")
  ,("senegal","\127480\127475")
  ,("serbia","\127479\127480")
  ,("service_dog","\128021\8205\129466")
  ,("seven","7\65039\8419")
  ,("seychelles","\127480\127464")
  ,("shallow_pan_of_food","\129368")
  ,("shamrock","\9752")
  ,("shark","\129416")
  ,("shaved_ice","\127847")
  ,("sheep","\128017")
  ,("shell","\128026")
  ,("shield","\128737")
  ,("shinto_shrine","\9961")
  ,("ship","\128674")
  ,("shirt","\128085")
  ,("shit","\128169")
  ,("shoe","\128094")
  ,("shopping","\128717")
  ,("shopping_cart","\128722")
  ,("shorts","\129651")
  ,("shower","\128703")
  ,("shrimp","\129424")
  ,("shrug","\129335")
  ,("shushing_face","\129323")
  ,("sierra_leone","\127480\127473")
  ,("signal_strength","\128246")
  ,("singapore","\127480\127468")
  ,("sint_maarten","\127480\127485")
  ,("six","6\65039\8419")
  ,("six_pointed_star","\128303")
  ,("skateboard","\128761")
  ,("ski","\127935")
  ,("skier","\9975")
  ,("skull","\128128")
  ,("skull_and_crossbones","\9760")
  ,("skunk","\129448")
  ,("sled","\128759")
  ,("sleeping","\128564")
  ,("sleeping_bed","\128716")
  ,("sleepy","\128554")
  ,("slightly_frowning_face","\128577")
  ,("slightly_smiling_face","\128578")
  ,("slot_machine","\127920")
  ,("sloth","\129445")
  ,("slovakia","\127480\127472")
  ,("slovenia","\127480\127470")
  ,("small_airplane","\128745")
  ,("small_blue_diamond","\128313")
  ,("small_orange_diamond","\128312")
  ,("small_red_triangle","\128314")
  ,("small_red_triangle_down","\128315")
  ,("smile","\128516")
  ,("smile_cat","\128568")
  ,("smiley","\128515")
  ,("smiley_cat","\128570")
  ,("smiling_face_with_three_hearts","\129392")
  ,("smiling_imp","\128520")
  ,("smirk","\128527")
  ,("smirk_cat","\128572")
  ,("smoking","\128684")
  ,("snail","\128012")
  ,("snake","\128013")
  ,("sneezing_face","\129319")
  ,("snowboarder","\127938")
  ,("snowflake","\10052\65039")
  ,("snowman","\9924")
  ,("snowman_with_snow","\9731\65039")
  ,("soap","\129532")
  ,("sob","\128557")
  ,("soccer","\9917")
  ,("socks","\129510")
  ,("softball","\129358")
  ,("solomon_islands","\127480\127463")
  ,("somalia","\127480\127476")
  ,("soon","\128284")
  ,("sos","\127384")
  ,("sound","\128265")
  ,("south_africa","\127487\127462")
  ,("south_georgia_south_sandwich_islands","\127468\127480")
  ,("south_sudan","\127480\127480")
  ,("space_invader","\128126")
  ,("spades","\9824\65039")
  ,("spaghetti","\127837")
  ,("sparkle","\10055\65039")
  ,("sparkler","\127879")
  ,("sparkles","\10024")
  ,("sparkling_heart","\128150")
  ,("speak_no_evil","\128586")
  ,("speaker","\128264")
  ,("speaking_head","\128483")
  ,("speech_balloon","\128172")
  ,("speedboat","\128676")
  ,("spider","\128375")
  ,("spider_web","\128376")
  ,("spiral_calendar","\128467")
  ,("spiral_notepad","\128466")
  ,("sponge","\129533")
  ,("spoon","\129348")
  ,("squid","\129425")
  ,("sri_lanka","\127473\127472")
  ,("st_barthelemy","\127463\127473")
  ,("st_helena","\127480\127469")
  ,("st_kitts_nevis","\127472\127475")
  ,("st_lucia","\127473\127464")
  ,("st_martin","\127474\127467")
  ,("st_pierre_miquelon","\127477\127474")
  ,("st_vincent_grenadines","\127483\127464")
  ,("stadium","\127967")
  ,("standing_man","\129485\8205\9794")
  ,("standing_person","\129485")
  ,("standing_woman","\129485\8205\9792")
  ,("star","\11088")
  ,("star2","\127775")
  ,("star_and_crescent","\9770")
  ,("star_of_david","\10017\65039")
  ,("star_struck","\129321")
  ,("stars","\127776")
  ,("station","\128649")
  ,("statue_of_liberty","\128509")
  ,("steam_locomotive","\128642")
  ,("stethoscope","\129658")
  ,("stew","\127858")
  ,("stop_button","\9209")
  ,("stop_sign","\128721")
  ,("stopwatch","\9201")
  ,("straight_ruler","\128207")
  ,("strawberry","\127827")
  ,("stuck_out_tongue","\128539")
  ,("stuck_out_tongue_closed_eyes","\128541")
  ,("stuck_out_tongue_winking_eye","\128540")
  ,("studio_microphone","\127897")
  ,("stuffed_flatbread","\129369")
  ,("sudan","\127480\127465")
  ,("sun_behind_large_cloud","\127781")
  ,("sun_behind_rain_cloud","\127782")
  ,("sun_behind_small_cloud","\127780")
  ,("sun_with_face","\127774")
  ,("sunflower","\127803")
  ,("sunglasses","\128526")
  ,("sunny","\9728\65039")
  ,("sunrise","\127749")
  ,("sunrise_over_mountains","\127748")
  ,("superhero","\129464")
  ,("superhero_man","\129464\8205\9794")
  ,("superhero_woman","\129464\8205\9792")
  ,("supervillain","\129465")
  ,("supervillain_man","\129465\8205\9794")
  ,("supervillain_woman","\129465\8205\9792")
  ,("surfer","\127940")
  ,("surfing_man","\127940\8205\9794")
  ,("surfing_woman","\127940\8205\9792")
  ,("suriname","\127480\127479")
  ,("sushi","\127843")
  ,("suspension_railway","\128671")
  ,("svalbard_jan_mayen","\127480\127471")
  ,("swan","\129442")
  ,("swaziland","\127480\127487")
  ,("sweat","\128531")
  ,("sweat_drops","\128166")
  ,("sweat_smile","\128517")
  ,("sweden","\127480\127466")
  ,("sweet_potato","\127840")
  ,("swim_brief","\129650")
  ,("swimmer","\127946")
  ,("swimming_man","\127946\8205\9794")
  ,("swimming_woman","\127946\8205\9792")
  ,("switzerland","\127464\127469")
  ,("symbols","\128291")
  ,("synagogue","\128333")
  ,("syria","\127480\127486")
  ,("syringe","\128137")
  ,("t-rex","\129430")
  ,("taco","\127790")
  ,("tada","\127881")
  ,("taiwan","\127481\127484")
  ,("tajikistan","\127481\127471")
  ,("takeout_box","\129377")
  ,("tanabata_tree","\127883")
  ,("tangerine","\127818")
  ,("tanzania","\127481\127487")
  ,("taurus","\9801")
  ,("taxi","\128661")
  ,("tea","\127861")
  ,("teddy_bear","\129528")
  ,("telephone","\9742\65039")
  ,("telephone_receiver","\128222")
  ,("telescope","\128301")
  ,("tennis","\127934")
  ,("tent","\9978")
  ,("test_tube","\129514")
  ,("thailand","\127481\127469")
  ,("thermometer","\127777")
  ,("thinking","\129300")
  ,("thought_balloon","\128173")
  ,("thread","\129525")
  ,("three","3\65039\8419")
  ,("thumbsdown","\128078")
  ,("thumbsup","\128077")
  ,("ticket","\127915")
  ,("tickets","\127903")
  ,("tiger","\128047")
  ,("tiger2","\128005")
  ,("timer_clock","\9202")
  ,("timor_leste","\127481\127473")
  ,("tipping_hand_man","\128129\8205\9794")
  ,("tipping_hand_person","\128129")
  ,("tipping_hand_woman","\128129\8205\9792")
  ,("tired_face","\128555")
  ,("tm","\8482\65039")
  ,("togo","\127481\127468")
  ,("toilet","\128701")
  ,("tokelau","\127481\127472")
  ,("tokyo_tower","\128508")
  ,("tomato","\127813")
  ,("tonga","\127481\127476")
  ,("tongue","\128069")
  ,("toolbox","\129520")
  ,("tooth","\129463")
  ,("top","\128285")
  ,("tophat","\127913")
  ,("tornado","\127786")
  ,("tr","\127481\127479")
  ,("trackball","\128434")
  ,("tractor","\128668")
  ,("traffic_light","\128677")
  ,("train","\128651")
  ,("train2","\128646")
  ,("tram","\128650")
  ,("triangular_flag_on_post","\128681")
  ,("triangular_ruler","\128208")
  ,("trident","\128305")
  ,("trinidad_tobago","\127481\127481")
  ,("tristan_da_cunha","\127481\127462")
  ,("triumph","\128548")
  ,("trolleybus","\128654")
  ,("trophy","\127942")
  ,("tropical_drink","\127865")
  ,("tropical_fish","\128032")
  ,("truck","\128666")
  ,("trumpet","\127930")
  ,("tshirt","\128085")
  ,("tulip","\127799")
  ,("tumbler_glass","\129347")
  ,("tunisia","\127481\127475")
  ,("turkey","\129411")
  ,("turkmenistan","\127481\127474")
  ,("turks_caicos_islands","\127481\127464")
  ,("turtle","\128034")
  ,("tuvalu","\127481\127483")
  ,("tv","\128250")
  ,("twisted_rightwards_arrows","\128256")
  ,("two","2\65039\8419")
  ,("two_hearts","\128149")
  ,("two_men_holding_hands","\128108")
  ,("two_women_holding_hands","\128109")
  ,("u5272","\127545")
  ,("u5408","\127540")
  ,("u55b6","\127546")
  ,("u6307","\127535")
  ,("u6708","\127543\65039")
  ,("u6709","\127542")
  ,("u6e80","\127541")
  ,("u7121","\127514")
  ,("u7533","\127544")
  ,("u7981","\127538")
  ,("u7a7a","\127539")
  ,("uganda","\127482\127468")
  ,("uk","\127468\127463")
  ,("ukraine","\127482\127462")
  ,("umbrella","\9748")
  ,("unamused","\128530")
  ,("underage","\128286")
  ,("unicorn","\129412")
  ,("united_arab_emirates","\127462\127466")
  ,("united_nations","\127482\127475")
  ,("unlock","\128275")
  ,("up","\127385")
  ,("upside_down_face","\128579")
  ,("uruguay","\127482\127486")
  ,("us","\127482\127480")
  ,("us_outlying_islands","\127482\127474")
  ,("us_virgin_islands","\127483\127470")
  ,("uzbekistan","\127482\127487")
  ,("v","\9996\65039")
  ,("vampire","\129499")
  ,("vampire_man","\129499\8205\9794")
  ,("vampire_woman","\129499\8205\9792")
  ,("vanuatu","\127483\127482")
  ,("vatican_city","\127483\127462")
  ,("venezuela","\127483\127466")
  ,("vertical_traffic_light","\128678")
  ,("vhs","\128252")
  ,("vibration_mode","\128243")
  ,("video_camera","\128249")
  ,("video_game","\127918")
  ,("vietnam","\127483\127475")
  ,("violin","\127931")
  ,("virgo","\9805")
  ,("volcano","\127755")
  ,("volleyball","\127952")
  ,("vomiting_face","\129326")
  ,("vs","\127386")
  ,("vulcan_salute","\128406")
  ,("waffle","\129479")
  ,("wales","\127988\917607\917602\917623\917612\917619\917631")
  ,("walking","\128694")
  ,("walking_man","\128694\8205\9794")
  ,("walking_woman","\128694\8205\9792")
  ,("wallis_futuna","\127484\127467")
  ,("waning_crescent_moon","\127768")
  ,("waning_gibbous_moon","\127766")
  ,("warning","\9888\65039")
  ,("wastebasket","\128465")
  ,("watch","\8986")
  ,("water_buffalo","\128003")
  ,("water_polo","\129341")
  ,("watermelon","\127817")
  ,("wave","\128075")
  ,("wavy_dash","\12336\65039")
  ,("waxing_crescent_moon","\127762")
  ,("waxing_gibbous_moon","\127764")
  ,("wc","\128702")
  ,("weary","\128553")
  ,("wedding","\128146")
  ,("weight_lifting","\127947")
  ,("weight_lifting_man","\127947\65039\8205\9794\65039")
  ,("weight_lifting_woman","\127947\65039\8205\9792\65039")
  ,("western_sahara","\127466\127469")
  ,("whale","\128051")
  ,("whale2","\128011")
  ,("wheel_of_dharma","\9784")
  ,("wheelchair","\9855")
  ,("white_check_mark","\9989")
  ,("white_circle","\9898")
  ,("white_flag","\127987")
  ,("white_flower","\128174")
  ,("white_haired_man","\128104\8205\129459")
  ,("white_haired_woman","\128105\8205\129459")
  ,("white_heart","\129293")
  ,("white_large_square","\11036")
  ,("white_medium_small_square","\9725")
  ,("white_medium_square","\9723\65039")
  ,("white_small_square","\9643\65039")
  ,("white_square_button","\128307")
  ,("wilted_flower","\129344")
  ,("wind_chime","\127888")
  ,("wind_face","\127788")
  ,("wine_glass","\127863")
  ,("wink","\128521")
  ,("wolf","\128058")
  ,("woman","\128105")
  ,("woman_artist","\128105\8205\127912")
  ,("woman_astronaut","\128105\8205\128640")
  ,("woman_cartwheeling","\129336\8205\9792")
  ,("woman_cook","\128105\8205\127859")
  ,("woman_dancing","\128131")
  ,("woman_facepalming","\129318\8205\9792")
  ,("woman_factory_worker","\128105\8205\127981")
  ,("woman_farmer","\128105\8205\127806")
  ,("woman_firefighter","\128105\8205\128658")
  ,("woman_health_worker","\128105\8205\9877")
  ,("woman_in_manual_wheelchair","\128105\8205\129469")
  ,("woman_in_motorized_wheelchair","\128105\8205\129468")
  ,("woman_judge","\128105\8205\9878")
  ,("woman_juggling","\129337\8205\9792")
  ,("woman_mechanic","\128105\8205\128295")
  ,("woman_office_worker","\128105\8205\128188")
  ,("woman_pilot","\128105\8205\9992")
  ,("woman_playing_handball","\129342\8205\9792")
  ,("woman_playing_water_polo","\129341\8205\9792")
  ,("woman_scientist","\128105\8205\128300")
  ,("woman_shrugging","\129335\8205\9792")
  ,("woman_singer","\128105\8205\127908")
  ,("woman_student","\128105\8205\127891")
  ,("woman_teacher","\128105\8205\127979")
  ,("woman_technologist","\128105\8205\128187")
  ,("woman_with_headscarf","\129493")
  ,("woman_with_probing_cane","\128105\8205\129455")
  ,("woman_with_turban","\128115\8205\9792")
  ,("womans_clothes","\128090")
  ,("womans_hat","\128082")
  ,("women_wrestling","\129340\8205\9792")
  ,("womens","\128698")
  ,("woozy_face","\129396")
  ,("world_map","\128506")
  ,("worried","\128543")
  ,("wrench","\128295")
  ,("wrestling","\129340")
  ,("writing_hand","\9997\65039")
  ,("x","\10060")
  ,("yarn","\129526")
  ,("yawning_face","\129393")
  ,("yellow_circle","\128993")
  ,("yellow_heart","\128155")
  ,("yellow_square","\129000")
  ,("yemen","\127486\127466")
  ,("yen","\128180")
  ,("yin_yang","\9775\65039")
  ,("yo_yo","\129664")
  ,("yum","\128523")
  ,("zambia","\127487\127474")
  ,("zany_face","\129322")
  ,("zap","\9889")
  ,("zebra","\129427")
  ,("zero","0\65039\8419")
  ,("zimbabwe","\127487\127484")
  ,("zipper_mouth_face","\129296")
  ,("zombie","\129503")
  ,("zombie_man","\129503\8205\9794")
  ,("zombie_woman","\129503\8205\9792")
  ,("zzz","\128164")
  ]

emojiToInline :: T.Text -> Maybe Inline
emojiToInline emojikey = makeSpan <$> M.lookup emojikey emojis
  where makeSpan = Span ("", ["emoji"], [("data-emoji", emojikey)]) . (:[]) . Str
